# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveConversationsFromCollection(BaseModel):
    remove_conversations_from_collection: Optional[
        "RemoveConversationsFromCollectionRemoveConversationsFromCollection"
    ] = Field(alias="removeConversationsFromCollection")


class RemoveConversationsFromCollectionRemoveConversationsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional[
                "RemoveConversationsFromCollectionRemoveConversationsFromCollectionContents"
            ]
        ]
    ]


class RemoveConversationsFromCollectionRemoveConversationsFromCollectionContents(
    BaseModel
):
    id: str
    name: str


RemoveConversationsFromCollection.model_rebuild()
RemoveConversationsFromCollectionRemoveConversationsFromCollection.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAlerts(BaseModel):
    delete_alerts: Optional[list[Optional["DeleteAlertsDeleteAlerts"]]] = Field(
        alias="deleteAlerts"
    )


class DeleteAlertsDeleteAlerts(BaseModel):
    id: str
    state: EntityState


DeleteAlerts.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleDriveDrives(BaseModel):
    google_drive_drives: Optional["QueryGoogleDriveDrivesGoogleDriveDrives"] = Field(
        alias="googleDriveDrives"
    )


class QueryGoogleDriveDrivesGoogleDriveDrives(BaseModel):
    results: Optional[list[Optional["QueryGoogleDriveDrivesGoogleDriveDrivesResults"]]]


class QueryGoogleDriveDrivesGoogleDriveDrivesResults(BaseModel):
    drive_id: Optional[str] = Field(alias="driveId")
    drive_name: Optional[str] = Field(alias="driveName")


QueryGoogleDriveDrives.model_rebuild()
QueryGoogleDriveDrivesGoogleDriveDrives.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes


class QueryGraph(BaseModel):
    graph: Optional["QueryGraphGraph"]


class QueryGraphGraph(BaseModel):
    nodes: Optional[list[Optional["QueryGraphGraphNodes"]]]
    edges: Optional[list[Optional["QueryGraphGraphEdges"]]]


class QueryGraphGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class QueryGraphGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


QueryGraph.model_rebuild()
QueryGraphGraph.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateLabel(BaseModel):
    update_label: Optional["UpdateLabelUpdateLabel"] = Field(alias="updateLabel")


class UpdateLabelUpdateLabel(BaseModel):
    id: str
    name: str


UpdateLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class ApproveContent(BaseModel):
    approve_content: Optional["ApproveContentApproveContent"] = Field(
        alias="approveContent"
    )


class ApproveContentApproveContent(BaseModel):
    id: str
    state: EntityState


ApproveContent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FactCategory, ObservableTypes, SourceTypes


class RetrieveFacts(BaseModel):
    retrieve_facts: Optional["RetrieveFactsRetrieveFacts"] = Field(
        alias="retrieveFacts"
    )


class RetrieveFactsRetrieveFacts(BaseModel):
    results: Optional[list[Optional["RetrieveFactsRetrieveFactsResults"]]]


class RetrieveFactsRetrieveFactsResults(BaseModel):
    fact: "RetrieveFactsRetrieveFactsResultsFact"
    relevance: Optional[float]
    content: Optional["RetrieveFactsRetrieveFactsResultsContent"]


class RetrieveFactsRetrieveFactsResultsFact(BaseModel):
    id: str
    creation_date: Any = Field(alias="creationDate")
    owner: "RetrieveFactsRetrieveFactsResultsFactOwner"
    state: EntityState
    text: str
    valid_at: Optional[Any] = Field(alias="validAt")
    invalid_at: Optional[Any] = Field(alias="invalidAt")
    relevance: Optional[float]
    mentions: Optional[list[Optional["RetrieveFactsRetrieveFactsResultsFactMentions"]]]
    assertions: Optional[
        list[Optional["RetrieveFactsRetrieveFactsResultsFactAssertions"]]
    ]
    feeds: Optional[list[Optional["RetrieveFactsRetrieveFactsResultsFactFeeds"]]]
    content: Optional["RetrieveFactsRetrieveFactsResultsFactContent"]
    conversation: Optional["RetrieveFactsRetrieveFactsResultsFactConversation"]
    persona: Optional["RetrieveFactsRetrieveFactsResultsFactPersona"]
    source_type: Optional[SourceTypes] = Field(alias="sourceType")
    category: Optional[FactCategory]
    confidence: Optional[float]


class RetrieveFactsRetrieveFactsResultsFactOwner(BaseModel):
    id: str


class RetrieveFactsRetrieveFactsResultsFactMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["RetrieveFactsRetrieveFactsResultsFactMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class RetrieveFactsRetrieveFactsResultsFactMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class RetrieveFactsRetrieveFactsResultsFactAssertions(BaseModel):
    text: str
    mentions: Optional[
        list[Optional["RetrieveFactsRetrieveFactsResultsFactAssertionsMentions"]]
    ]


class RetrieveFactsRetrieveFactsResultsFactAssertionsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional[
        "RetrieveFactsRetrieveFactsResultsFactAssertionsMentionsObservable"
    ]
    start: Optional[int]
    end: Optional[int]


class RetrieveFactsRetrieveFactsResultsFactAssertionsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class RetrieveFactsRetrieveFactsResultsFactFeeds(BaseModel):
    id: str
    name: str


class RetrieveFactsRetrieveFactsResultsFactContent(BaseModel):
    id: str
    name: str


class RetrieveFactsRetrieveFactsResultsFactConversation(BaseModel):
    id: str
    name: str


class RetrieveFactsRetrieveFactsResultsFactPersona(BaseModel):
    id: str
    name: str


class RetrieveFactsRetrieveFactsResultsContent(BaseModel):
    id: str


RetrieveFacts.model_rebuild()
RetrieveFactsRetrieveFacts.model_rebuild()
RetrieveFactsRetrieveFactsResults.model_rebuild()
RetrieveFactsRetrieveFactsResultsFact.model_rebuild()
RetrieveFactsRetrieveFactsResultsFactMentions.model_rebuild()
RetrieveFactsRetrieveFactsResultsFactAssertions.model_rebuild()
RetrieveFactsRetrieveFactsResultsFactAssertionsMentions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySlackUsers(BaseModel):
    slack_users: Optional["QuerySlackUsersSlackUsers"] = Field(alias="slackUsers")


class QuerySlackUsersSlackUsers(BaseModel):
    results: Optional[list[Optional["QuerySlackUsersSlackUsersResults"]]]


class QuerySlackUsersSlackUsersResults(BaseModel):
    user_id: str = Field(alias="userId")
    display_name: str = Field(alias="displayName")
    real_name: Optional[str] = Field(alias="realName")
    email: Optional[str]


QuerySlackUsers.model_rebuild()
QuerySlackUsersSlackUsers.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableAgent(BaseModel):
    disable_agent: Optional["DisableAgentDisableAgent"] = Field(alias="disableAgent")


class DisableAgentDisableAgent(BaseModel):
    id: str
    state: EntityState


DisableAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class LookupPersons(BaseModel):
    lookup_persons: Optional["LookupPersonsLookupPersons"] = Field(
        alias="lookupPersons"
    )


class LookupPersonsLookupPersons(BaseModel):
    results: Optional[list[Optional["LookupPersonsLookupPersonsResults"]]]


class LookupPersonsLookupPersonsResults(BaseModel):
    name: Optional[str]
    title: Optional[str]
    headline: Optional[str]
    location: Optional[str]
    linked_in_url: Optional[Any] = Field(alias="linkedInUrl")
    email: Optional[str]
    profile_picture_url: Optional[Any] = Field(alias="profilePictureUrl")
    current_company: Optional[str] = Field(alias="currentCompany")
    current_title: Optional[str] = Field(alias="currentTitle")
    skills: Optional[list[Optional[str]]]
    years_of_experience: Optional[float] = Field(alias="yearsOfExperience")


LookupPersons.model_rebuild()
LookupPersonsLookupPersons.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class ExtractText(BaseModel):
    extract_text: Optional[list[Optional["ExtractTextExtractText"]]] = Field(
        alias="extractText"
    )


class ExtractTextExtractText(BaseModel):
    specification: Optional["ExtractTextExtractTextSpecification"]
    content: Optional["ExtractTextExtractTextContent"]
    name: str
    value: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    error: Optional[str]


class ExtractTextExtractTextSpecification(BaseModel):
    id: str


class ExtractTextExtractTextContent(BaseModel):
    id: str


ExtractText.model_rebuild()
ExtractTextExtractText.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class MapWeb(BaseModel):
    map_web: Optional["MapWebMapWeb"] = Field(alias="mapWeb")


class MapWebMapWeb(BaseModel):
    results: Optional[list[Optional[Any]]]


MapWeb.model_rebuild()
